from setuptools import setup

setup(name = 'gau&bi_distributions',
      version = '0.1',
      description = 'Gaussian and Binomial distributions',
      packages = ['gau&bi_distributions'],
      author = 'Morufdeen Atilola',
      author_email = 'atilolamorufdeen@gmail.com',
      zip_safe=False)
